@@ -6,17 +6,18 @@ from typing import Tuple, List
 
 import numpy as np
 
-from pydwf.core.dwf_device_subapi import DwfDeviceSubApi
+from pydwf.core.dwf_device_subapi import AbstractDwfDeviceSubApi
 
 from pydwf.core.auxiliary.typespec_ctypes import typespec_ctypes
-from pydwf.core.auxiliary.enum_types import (DwfTriggerLengthCondition, DwfTriggerSource, DwfTriggerType,
-                                             DwfTriggerSlope, DwfAnalogInFilter, DwfAcquisitionMode, DwfState)
+from pydwf.core.auxiliary.enum_types import (DwfAnalogInTriggerLengthCondition, DwfTriggerSource,
+                                             DwfAnalogInTriggerType, DwfTriggerSlope, DwfAnalogInFilter,
+                                             DwfAcquisitionMode, DwfState)
 from pydwf.core.auxiliary.constants import RESULT_SUCCESS
 from pydwf.core.auxiliary.exceptions import PyDwfError
 
 
-class AnalogIn(DwfDeviceSubApi):
-    """The |AnalogIn| class provides access to the AnalogIn (oscilloscope) instrument of a |DwfDevice:link|.
+class AnalogIn(AbstractDwfDeviceSubApi):
+    """The |AnalogIn| class provides access to the analog input (oscilloscope) instrument of a |DwfDevice:link|.
 
     Attention:
         Users of |pydwf| should not create instances of this class directly.
@@ -34,7 +35,7 @@ class AnalogIn(DwfDeviceSubApi):
     ####################################################################################################################
 
     def reset(self) -> None:
-        """Reset all AnalogIn instrument parameters to default values.
+        """Reset all |AnalogIn| instrument parameters to default values.
 
         If auto-configuration is enabled at the device level, the reset operation is performed immediately;
         otherwise, an explicit call to the :py:meth:`configure` method is required.
@@ -62,19 +63,19 @@ class AnalogIn(DwfDeviceSubApi):
             raise self.dwf.exception()
 
     def status(self, read_data: bool) -> DwfState:
-        """Check the status of the instrument.
+        """Get |AnalogIn| instrument state.
 
-        Executing this method initiates a status request to the AnalogIn instrument and receives its response.
+        Executing this method initiates a status request to the |AnalogIn| instrument and receives its response.
 
-        The following methods can be used to retrieve *AnalogIn* instrument status information
+        The following methods can be used to retrieve |AnalogIn| instrument status information
         as a result of this call, regardless of the value of *read_data*:
 
-        * :py:meth:`~statusSamplesLeft`
         * :py:meth:`~statusTime`
+        * :py:meth:`~statusSample`
+        * :py:meth:`~statusAutoTriggered`
+        * :py:meth:`~statusSamplesLeft`
         * :py:meth:`~statusSamplesValid`
         * :py:meth:`~statusIndexWrite`
-        * :py:meth:`~statusAutoTriggered`
-        * :py:meth:`~statusSample`
         * :py:meth:`~statusRecord`
 
         The following methods can be used to retrieve bulk data obtained from the *AnalogIn* instrument
@@ -86,14 +87,14 @@ class AnalogIn(DwfDeviceSubApi):
         * :py:meth:`~statusNoise`
         * :py:meth:`~statusNoise2`
 
-        Arguments:
+        Parameters:
             read_data (bool): If True, read sample data from the instrument.
 
                 For :py:attr:`~pydwf.core.auxiliary.enum_types.DwfAcquisitionMode.Single` acquisition mode,
                 the data will be read only when the acquisition is finished.
 
         Returns:
-            DwfState: The status of the AnalogIn instrument.
+            DwfState: The status of the |AnalogIn| instrument.
 
         Raises:
             DwfLibraryError: There was an error while executing the *status* operation.
@@ -137,10 +138,10 @@ class AnalogIn(DwfDeviceSubApi):
         return (sec_utc, tick, ticks_per_second)
 
     def statusSample(self, channel_index: int) -> float:
-        """Get the last ADC conversion sample from the specified AnalogIn instrument channel, in Volts.
+        """Get the last ADC conversion sample from the specified |AnalogIn| instrument channel, in Volts.
 
         Note:
-            This value is updated even if the `status` method is called with argument False.
+            This value is updated even if the :py:meth:`status` method is called with argument False.
 
         Parameters:
             channel_index: int: The channel index, in the range 0 to :py:meth:`channelCount`-1.
@@ -159,7 +160,7 @@ class AnalogIn(DwfDeviceSubApi):
         return sample
 
     def statusAutoTriggered(self) -> bool:
-        """Verify if the current acquisition is auto-triggered.
+        """Check if the current acquisition is auto-triggered.
 
         Returns:
             bool: True if the current acquisition is auto-triggered, False otherwise.
@@ -178,7 +179,8 @@ class AnalogIn(DwfDeviceSubApi):
         """Retrieve the number of samples left in the acquisition, in samples.
 
         Returns:
-            int: In case a finite-duration acquisition is active, the number of samples left in the acquisition.
+            int: In case a finite-duration acquisition is active, the number of samples
+            remaining to be acquired in the acquisition.
 
         Raises:
             DwfLibraryError: There was an error while retrieving the number of samples left.
@@ -214,7 +216,8 @@ class AnalogIn(DwfDeviceSubApi):
     def statusIndexWrite(self) -> int:
         """Retrieve the buffer write index.
 
-        This is needed in *ScanScreen* acquisition mode to display the scan bar.
+        This is needed in :py:attr:`~pydwf.core.auxiliary.enum_types.DwfAcquisitionMode.ScanScreen`
+        acquisition mode to display the scan bar.
 
         Returns:
             int: The buffer write index.
@@ -244,7 +247,7 @@ class AnalogIn(DwfDeviceSubApi):
         equal to buffer_size / sample_frequency).
 
         Returns:
-            Tuple[int, int, int]: A three-element tuple containing three counts for
+            Tuple[int, int, int]: A three-element tuple containing the counts for
                 *available*, *lost*, and *corrupt* data samples, in that order.
 
         Raises:
@@ -272,7 +275,7 @@ class AnalogIn(DwfDeviceSubApi):
     ####################################################################################################################
 
     def statusData(self, channel_index: int, count: int) -> np.ndarray:
-        """Retrieve the acquired data samples from the specified AnalogIn instrument channel.
+        """Retrieve the acquired data samples from the specified |AnalogIn| instrument channel.
 
         This method returns samples as voltages, calculated from the raw, binary sample values as follows:
 
@@ -286,6 +289,7 @@ class AnalogIn(DwfDeviceSubApi):
         Parameters:
             channel_index: int: The channel index, in the range 0 to :py:meth:`channelCount`-1.
             count: int: The number of samples to retrieve.
+
         Returns:
             A 1D numpy array of floats, in Volts.
 
@@ -303,7 +307,7 @@ class AnalogIn(DwfDeviceSubApi):
         return samples
 
     def statusData2(self, channel_index: int, offset: int, count: int) -> np.ndarray:
-        """Retrieve the acquired data samples from the specified AnalogIn instrument channel.
+        """Retrieve the acquired data samples from the specified |AnalogIn| instrument channel.
 
         This method returns samples as voltages, calculated from the raw, binary sample values as follows:
 
@@ -319,6 +323,7 @@ class AnalogIn(DwfDeviceSubApi):
             channel_index (int): The channel index, in the range 0 to :py:meth:`channelCount`-1.
             offset (int): Sample offset.
             count (int): Sample count.
+
         Returns:
             A 1D numpy array of floats, in Volts.
 
@@ -337,7 +342,7 @@ class AnalogIn(DwfDeviceSubApi):
         return samples
 
     def statusData16(self, channel_index: int, offset: int, count: int) -> np.ndarray:
-        """Retrieve the acquired data samples from the specified AnalogIn instrument channel.
+        """Retrieve the acquired data samples from the specified |AnalogIn| instrument channel.
 
         This method returns raw, signed 16-bit samples.
 
@@ -374,7 +379,7 @@ class AnalogIn(DwfDeviceSubApi):
         return samples
 
     def statusNoise(self, channel_index: int, count: int) -> Tuple[np.ndarray, np.ndarray]:
-        """Retrieve the acquired noise samples from the specified AnalogIn instrument channel.
+        """Retrieve the acquired noise samples from the specified |AnalogIn| instrument channel.
 
         Parameters:
             channel_index (int): The channel index, in the range 0 to :py:meth:`channelCount`-1.
@@ -383,7 +388,7 @@ class AnalogIn(DwfDeviceSubApi):
         Returns:
             A two-element tuple; each element is a 1D numpy array of floats, in Volts.
 
-            The first array contains the minimum values, the second element contains the maximum values.
+            The first array contains the minimum values, the second array contains the maximum values.
 
         Raises:
             DwfLibraryError: There was an error while retrieving the noise data.
@@ -411,7 +416,7 @@ class AnalogIn(DwfDeviceSubApi):
         Returns:
             A two-element tuple; each element is a 1D numpy array of floats, in Volts.
 
-            The first array contains the minimum values, the second element contains the maximum values.
+            The first array contains the minimum values, the second array contains the maximum values.
 
         Raises:
             DwfLibraryError: There was an error while retrieving the noise data.
@@ -436,18 +441,16 @@ class AnalogIn(DwfDeviceSubApi):
     ####################################################################################################################
 
     def bitsInfo(self) -> int:
-        """Get the fixed the number of bits used by the AnalogIn ADC.
+        """Get the fixed the number of bits used by the |AnalogIn| ADC.
 
         This number of bits can only be queried; it cannot be changed.
 
         Note:
-            The Analog Discovery 2 uses an `Analog Devices AD9648
-            <https://www.analog.com/media/en/technical-documentation/data-sheets/AD9648.pdf>`_ two-channel ADC.
-            It converts 14-bit samples at a rate of up to 125 MHz. So for the Analog Discovery 2, this method
-            always returns 14.
+            The Analog Discovery 2 uses an |Analog Devices AD964| two-channel ADC. It converts 14-bit samples at a rate
+            of up to 125 MHz. So for the Analog Discovery 2, this method always returns 14.
 
         Returns:
-            int: The number of bits per sample for each of the AnalogIn channels.
+            int: The number of bits per sample for each of the |AnalogIn| channels.
 
         Raises:
             DwfLibraryError: There was an error while getting the number of bits.
@@ -463,7 +466,8 @@ class AnalogIn(DwfDeviceSubApi):
         """Set the record length, in seconds.
 
         Note:
-            This value is only used when the acquisition mode is configured as *Record*.
+            This value is only used when the acquisition mode is configured as
+            :py:attr:`~pydwf.core.auxiliary.enum_types.DwfAcquisitionMode.Record`.
 
         Parameters:
             record_duration (float): The record duration to be configured, in seconds.
@@ -481,7 +485,8 @@ class AnalogIn(DwfDeviceSubApi):
         """Get the record length, in seconds.
 
         Note:
-            This value is only used when the acquisition mode is configured as *Record*.
+            This value is only used when the acquisition mode is configured as
+            :py:attr:`~pydwf.core.auxiliary.enum_types.DwfAcquisitionMode.Record`.
 
         Returns:
             float: The currently configured record length, in seconds.
@@ -517,7 +522,7 @@ class AnalogIn(DwfDeviceSubApi):
         return (frequency_min, frequency_max)
 
     def frequencySet(self, sample_frequency: float) -> None:
-        """Set the ADC sample frequency of the AnalogIn instrument, in samples/second.
+        """Set the ADC sample frequency of the |AnalogIn| instrument, in samples/second.
 
         Parameters:
             sample_frequency (float): Sample frequency, in samples/second.
@@ -530,7 +535,7 @@ class AnalogIn(DwfDeviceSubApi):
             raise self.dwf.exception()
 
     def frequencyGet(self) -> float:
-        """Get the ADC sample frequency of the AnalogIn instrument, in samples/second.
+        """Get the ADC sample frequency of the |AnalogIn| instrument, in samples/second.
 
         The ADC always runs at maximum frequency, but the method in which the samples are stored and transferred
         can be configured individually for each channel with the `channelFilterSet` method.
@@ -551,15 +556,16 @@ class AnalogIn(DwfDeviceSubApi):
     def bufferSizeInfo(self) -> Tuple[int, int]:
         """Returns the minimum and maximum allowable buffer size for the instrument, in samples.
 
-        When using the *Record* acquisition mode, the buffer size should be left at the default value, which is equal
-        to the maximum value. In other modes (e.g. *Single*), the buffer size determines the size of the
-        acquisition window.
+        When using the :py:attr:`~pydwf.core.auxiliary.enum_types.DwfAcquisitionMode.Record` acquisition mode,
+        the buffer size should be left at the default value, which is equal to the maximum value.
+        In other modes (e.g. :py:attr:`~pydwf.core.auxiliary.enum_types.DwfAcquisitionMode.Single`), the buffer
+        size determines the size of the acquisition window.
 
         Note:
-            The maximum buffer size depends on the configuration that was selected while opening the device.
+            The maximum buffer size depends on the device configuration that was selected while opening the device.
 
-            For example, on the Analog Discovery 2, maximum AnalogIn buffer size can be 512, 2048, 8192, or 16384,
-            depending on the configuration.
+            For example, on the Analog Discovery 2, the maximum |AnalogIn| buffer size can be 512, 2048, 8192, or
+            16384, depending on the device configuration.
 
         Returns:
             Tuple[int, int]: A two-element tuple.
@@ -578,11 +584,11 @@ class AnalogIn(DwfDeviceSubApi):
         return (buffer_size_min, buffer_size_max)
 
     def bufferSizeSet(self, buffer_size: int) -> None:
-        """Adjust the AnalogIn instrument buffer size, expressed in samples.
+        """Adjust the |AnalogIn| instrument buffer size, expressed in samples.
 
-        The actual buffer size configured will be clipped by the `bufferSizeInfo` values.
+        The actual buffer size configured will be clipped by the :py:meth:`bufferSizeInfo` values.
 
-        The actual value configured can be read back by calling `bufferSizeGet`.
+        The actual value configured can be read back by calling :py:meth:`bufferSizeGet`.
 
         Parameters:
             buffer_size (int): The requested buffer size, in samples.
@@ -595,7 +601,7 @@ class AnalogIn(DwfDeviceSubApi):
             raise self.dwf.exception()
 
     def bufferSizeGet(self) -> int:
-        """Return the used AnalogIn instrument buffer size, in samples.
+        """Return the used |AnalogIn| instrument buffer size, in samples.
 
         Returns:
             int: The currently configured buffer size, in samples.
@@ -611,7 +617,7 @@ class AnalogIn(DwfDeviceSubApi):
         return buffer_size
 
     def noiseSizeInfo(self) -> int:
-        """Return the maximum noise buffer size for the AnalogIn instrument, in samples.
+        """Return the maximum noise buffer size for the |AnalogIn| instrument, in samples.
 
         Returns:
             The maximum noise buffer size, in samples.
@@ -627,7 +633,7 @@ class AnalogIn(DwfDeviceSubApi):
         return nSizeMax
 
     def noiseSizeSet(self, noise_buffer_size: int) -> None:
-        """Enable or disable the noise buffer.
+        """Enable or disable the noise buffer for the |AnalogIn| instrument.
 
         This method determines if the noise buffer is enabled or disabled.
 
@@ -651,7 +657,7 @@ class AnalogIn(DwfDeviceSubApi):
             raise self.dwf.exception()
 
     def noiseSizeGet(self) -> int:
-        """Return the currently configured noise buffer size for the AnalogIn instrument, in samples.
+        """Return the currently configured noise buffer size for the |AnalogIn| instrument, in samples.
 
         This value is automatically adjusted according to the sample buffer size, divided by 8.
         For instance, setting the sample buffer size of 8192 implies a noise buffer size of 1024;
@@ -671,10 +677,10 @@ class AnalogIn(DwfDeviceSubApi):
         return noise_buffer_size
 
     def acquisitionModeInfo(self) -> List[DwfAcquisitionMode]:
-        """Return the supported AnalogIn acquisition modes.
+        """Return the supported |AnalogIn| acquisition modes.
 
         Returns:
-            List[DwfAcquisitionMode]: A list of acquisition modes supported by the AnalogIn instrument.
+            List[DwfAcquisitionMode]: A list of acquisition modes supported by the |AnalogIn| instrument.
 
         Raises:
             DwfLibraryError: There was an error while getting the acquisition mode info.
@@ -690,7 +696,7 @@ class AnalogIn(DwfDeviceSubApi):
         return acquisition_mode_list
 
     def acquisitionModeSet(self, acquisition_mode: DwfAcquisitionMode) -> None:
-        """Set the acquisition mode.
+        """Set the |AnalogIn| acquisition mode.
 
         Parameters:
             acquisition_mode (DwfAcquisitionMode): The acquisition mode to be configured.
@@ -703,7 +709,7 @@ class AnalogIn(DwfDeviceSubApi):
             raise self.dwf.exception()
 
     def acquisitionModeGet(self) -> DwfAcquisitionMode:
-        """Get the currently configured acquisition mode.
+        """Get the currently configured |AnalogIn| acquisition mode.
 
         Returns:
             DwfAcquisitionMode: The acquisition mode currently configured.
@@ -711,7 +717,7 @@ class AnalogIn(DwfDeviceSubApi):
         Raises:
             DwfLibraryError: There was an error while getting the acquisition mode.
         """
-        c_acquisition_mode = typespec_ctypes.ACQMODE()
+        c_acquisition_mode = typespec_ctypes.DwfAcquisitionMode()
         result = self.lib.FDwfAnalogInAcquisitionModeGet(self.hdwf, c_acquisition_mode)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
@@ -761,7 +767,7 @@ class AnalogIn(DwfDeviceSubApi):
             raise self.dwf.exception()
 
     def channelEnableGet(self, channel_index: int) -> bool:
-        """Get the current enable/disable status of the specified AnalogIn channel.
+        """Get the current enable/disable status of the specified |AnalogIn| channel.
 
         Parameters:
             channel_index: int: The channel index, in the range 0 to :py:meth:`channelCount`-1.
@@ -823,7 +829,7 @@ class AnalogIn(DwfDeviceSubApi):
         Raises:
             DwfLibraryError: There was an error while getting the current channel filter setting.
         """
-        c_channel_filter = typespec_ctypes.FILTER()
+        c_channel_filter = typespec_ctypes.DwfAnalogInFilter()
         result = self.lib.FDwfAnalogInChannelFilterGet(self.hdwf, channel_index, c_channel_filter)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
@@ -1011,7 +1017,7 @@ class AnalogIn(DwfDeviceSubApi):
 
         Parameters:
             channel_index: int: The channel index, in the range 0 to :py:meth:`channelCount`-1.
-            attenuation: float: The requested channel attenuation setting.
+            channel_attenuation: float: The requested channel attenuation setting.
                 If it is 0.0, the attenuation is set to 1.0 (the default) instead.
 
         Raises:
@@ -1058,7 +1064,7 @@ class AnalogIn(DwfDeviceSubApi):
 
         Parameters:
             channel_index: int: The channel index, in the range 0 to :py:meth:`channelCount`-1.
-            bandwidth: float: The channel bandwidth setting, in Hz.
+            channel_bandwidth: float: The channel bandwidth setting, in Hz.
 
         Note:
             On the Analog Discovery 2, the channel bandwidth setting exists and can be set and retrieved,
@@ -1099,7 +1105,7 @@ class AnalogIn(DwfDeviceSubApi):
 
         Parameters:
             channel_index: int: The channel index, in the range 0 to :py:meth:`channelCount`-1.
-            impedance: float: channel impedance setting, in Ohms.
+            channel_impedance: float: channel impedance setting, in Ohms.
 
         Note:
             On the Analog Discovery 2, the channel impedance setting exists and can be set and retrieved,
@@ -1142,7 +1148,7 @@ class AnalogIn(DwfDeviceSubApi):
     ####################################################################################################################
 
     def triggerSourceInfo(self) -> List[DwfTriggerSource]:
-        """Get analog-in trigger source info.
+        """Get the |AnalogIn| instrument trigger source info.
 
         Warning:
             This method is obsolete. Use the generic |DwfDevice.triggerInfo:link| method instead.
@@ -1163,7 +1169,7 @@ class AnalogIn(DwfDeviceSubApi):
         return trigger_source_list
 
     def triggerSourceSet(self, trigger_source: DwfTriggerSource) -> None:
-        """Set the trigger source.
+        """Set the |AnalogIn| instrument trigger source.
 
         Parameters:
             trigger_source (DwfTriggerSource): The trigger source to be selected.
@@ -1176,7 +1182,7 @@ class AnalogIn(DwfDeviceSubApi):
             raise self.dwf.exception()
 
     def triggerSourceGet(self) -> DwfTriggerSource:
-        """Get the trigger source.
+        """Get the |AnalogIn| instrument trigger source.
 
         Returns:
             DwfTriggerSource: The currently selected trigger source value.
@@ -1184,7 +1190,7 @@ class AnalogIn(DwfDeviceSubApi):
         Raises:
             DwfLibraryError: There was an error while retrieving the active trigger source.
         """
-        c_trigger_source = typespec_ctypes.TRIGSRC()
+        c_trigger_source = typespec_ctypes.DwfTriggerSource()
         result = self.lib.FDwfAnalogInTriggerSourceGet(self.hdwf, c_trigger_source)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
@@ -1192,7 +1198,7 @@ class AnalogIn(DwfDeviceSubApi):
         return trigger_source
 
     def triggerPositionInfo(self) -> Tuple[float, float, int]:
-        """Get trigger position info.
+        """Get the |AnalogIn| instrument trigger position info.
 
         Returns:
             Tuple[float, float, int]: The valid range of trigger positions that can be configured.
@@ -1221,7 +1227,7 @@ class AnalogIn(DwfDeviceSubApi):
         return (trigger_position_min, trigger_position_max, trigger_position_num_steps)
 
     def triggerPositionSet(self, trigger_position: float) -> None:
-        """Set the trigger position.
+        """Set the |AnalogIn| instrument trigger position.
 
         In recording mode, the trigger position is the time, in seconds, relative to the position of the trigger event,
         of the first valid sample acquired. Negative values indicates times before the trigger time.
@@ -1242,7 +1248,7 @@ class AnalogIn(DwfDeviceSubApi):
             raise self.dwf.exception()
 
     def triggerPositionGet(self) -> float:
-        """Get the trigger position.
+        """Get the |AnalogIn| instrument trigger position.
 
         Returns:
             float: The currently configured trigger position, in seconds.
@@ -1258,7 +1264,7 @@ class AnalogIn(DwfDeviceSubApi):
         return trigger_position
 
     def triggerPositionStatus(self) -> float:
-        """Get the current trigger position status.
+        """Get the current |AnalogIn| instrument trigger position status.
 
         Returns:
             float: The current trigger position, in seconds.
@@ -1273,34 +1279,8 @@ class AnalogIn(DwfDeviceSubApi):
         trigger_position = c_trigger_position.value
         return trigger_position
 
-    ####################################################################################################################
-    #                                                                                                                  #
-    #                                               FORCE INSTRUMENT TRIGGER                                           #
-    #                                                                                                                  #
-    ####################################################################################################################
-
-    def triggerForce(self) -> None:
-        """Force assertion of the instrument trigger.
-
-        Note:
-            This method forces the |AnalogIn| device to act as if it was triggered, independent of the currently
-            active trigger source. It does not generate an artificial trigger event on the |AnalogIn| trigger detector.
-
-        Raises:
-            DwfLibraryError: There was an error while executing the operation.
-        """
-        result = self.lib.FDwfAnalogInTriggerForce(self.hdwf)
-        if result != RESULT_SUCCESS:
-            raise self.dwf.exception()
-
-    ####################################################################################################################
-    #                                                                                                                  #
-    #                                               TRIGGER DETECTOR CONFIGURATION                                     #
-    #                                                                                                                  #
-    ####################################################################################################################
-
     def triggerAutoTimeoutInfo(self) -> Tuple[float, float, int]:
-        """Get trigger auto-timeout info.
+        """Get the |AnalogIn| instrument trigger auto-timeout info.
 
         Returns:
             Tuple[float, float, int]: The valid range of trigger auto-timeout values that can be configured.
@@ -1329,10 +1309,10 @@ class AnalogIn(DwfDeviceSubApi):
         return (auto_timeout_min, auto_timeout_max, auto_timeout_num_steps)
 
     def triggerAutoTimeoutSet(self, trigger_autotimeout: float) -> None:
-        """Set the trigger auto-timeout value.
+        """Set the |AnalogIn| instrument trigger auto-timeout value.
 
         Parameters:
-            timeout_setting (float): The auto timeout setting, in seconds.
+            trigger_autotimeout (float): The auto timeout setting, in seconds.
 
         Raises:
             DwfLibraryError: There was an error while setting the trigger auto-timeout value.
@@ -1342,7 +1322,7 @@ class AnalogIn(DwfDeviceSubApi):
             raise self.dwf.exception()
 
     def triggerAutoTimeoutGet(self) -> float:
-        """Get trigger auto-timeout value.
+        """Get the |AnalogIn| instrument trigger auto-timeout value.
 
         Returns:
             float: The currently configured auto-timeout value, in seconds.
@@ -1357,8 +1337,34 @@ class AnalogIn(DwfDeviceSubApi):
         trigger_autotimeout = c_trigger_autotimeout.value
         return trigger_autotimeout
 
+    ####################################################################################################################
+    #                                                                                                                  #
+    #                                               FORCE INSTRUMENT TRIGGER                                           #
+    #                                                                                                                  #
+    ####################################################################################################################
+
+    def triggerForce(self) -> None:
+        """Force assertion of the instrument trigger.
+
+        Note:
+            This method forces the |AnalogIn| device to act as if it was triggered, independent of the currently
+            active trigger source. It does not generate an artificial trigger event on the |AnalogIn| trigger detector.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
+        result = self.lib.FDwfAnalogInTriggerForce(self.hdwf)
+        if result != RESULT_SUCCESS:
+            raise self.dwf.exception()
+
+    ####################################################################################################################
+    #                                                                                                                  #
+    #                                               TRIGGER DETECTOR CONFIGURATION                                     #
+    #                                                                                                                  #
+    ####################################################################################################################
+
     def triggerHoldOffInfo(self) -> Tuple[float, float, int]:
-        """Get trigger holdoff info.
+        """Get |AnalogIn| trigger detector holdoff info.
 
         The trigger holdoff setting is the minimum time (in seconds) for a trigger to be
         recognized after a previous trigger.
@@ -1391,10 +1397,10 @@ class AnalogIn(DwfDeviceSubApi):
         return (trigger_holdoff_min, trigger_holdoff_max, trigger_holdoff_num_steps)
 
     def triggerHoldOffSet(self, trigger_holdoff: float) -> None:
-        """Set trigger holdoff value.
+        """Set |AnalogIn| trigger detector  holdoff value.
 
         Parameters:
-            holdoff_setting (float): The holdoff setting, in seconds.
+            trigger_holdoff (float): The holdoff setting, in seconds.
 
         Raises:
             DwfLibraryError: There was an error while setting the trigger holdoff value.
@@ -1404,7 +1410,7 @@ class AnalogIn(DwfDeviceSubApi):
             raise self.dwf.exception()
 
     def triggerHoldOffGet(self) -> float:
-        """Get trigger holdoff value.
+        """Get current |AnalogIn| trigger detector holdoff value.
 
         Returns:
             float: The currently configured trigger holdoff value, in seconds.
@@ -1419,11 +1425,11 @@ class AnalogIn(DwfDeviceSubApi):
         trigger_holdoff = c_trigger_holdoff.value
         return trigger_holdoff
 
-    def triggerTypeInfo(self) -> List[DwfTriggerType]:
-        """Get the trigger type info.
+    def triggerTypeInfo(self) -> List[DwfAnalogInTriggerType]:
+        """Get the |AnalogIn| trigger detector trigger type info.
 
         Returns:
-            List[DwfTriggerType]: A list of trigger types that can be configured.
+            List[DwfAnalogInTriggerType]: A list of trigger types that can be configured.
 
         Raises:
             DwfLibraryError: There was an error while getting the trigger type info.
@@ -1433,15 +1439,15 @@ class AnalogIn(DwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
         trigger_type_bitset = c_trigger_type_bitset.value
-        trigger_type_list = [trigger_type for trigger_type in DwfTriggerType
+        trigger_type_list = [trigger_type for trigger_type in DwfAnalogInTriggerType
                              if trigger_type_bitset & (1 << trigger_type.value)]
         return trigger_type_list
 
-    def triggerTypeSet(self, trigger_type: DwfTriggerType) -> None:
-        """Set the trigger type.
+    def triggerTypeSet(self, trigger_type: DwfAnalogInTriggerType) -> None:
+        """Set the |AnalogIn| trigger detector trigger type.
 
         Parameters:
-            trigger_type (DwfTriggerType): The trigger type to be configured.
+            trigger_type (DwfAnalogInTriggerType): The trigger type to be configured.
 
         Raises:
             DwfLibraryError: There was an error while setting the trigger type.
@@ -1450,24 +1456,24 @@ class AnalogIn(DwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def triggerTypeGet(self) -> DwfTriggerType:
-        """Get the trigger type.
+    def triggerTypeGet(self) -> DwfAnalogInTriggerType:
+        """Get the |AnalogIn| trigger detector trigger type.
 
         Returns:
-            DwfTriggerType: The currently configured trigger type.
+            DwfAnalogInTriggerType: The currently configured trigger type.
 
         Raises:
             DwfLibraryError: There was an error while getting the trigger type.
         """
-        c_trigger_type = typespec_ctypes.TRIGTYPE()
+        c_trigger_type = typespec_ctypes.DwfAnalogInTriggerType()
         result = self.lib.FDwfAnalogInTriggerTypeGet(self.hdwf, c_trigger_type)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        trigger_type = DwfTriggerType(c_trigger_type.value)
+        trigger_type = DwfAnalogInTriggerType(c_trigger_type.value)
         return trigger_type
 
     def triggerChannelInfo(self) -> Tuple[int, int]:
-        """Get |AnalogIn| trigger detector channel info.
+        """Get the |AnalogIn| trigger detector channel info.
 
         The |AnalogIn| trigger detector is sensitive to a specific channel.
         This method returns the range of valid analog input channels that can be configured
@@ -1525,7 +1531,7 @@ class AnalogIn(DwfDeviceSubApi):
         return trigger_channel_index
 
     def triggerFilterInfo(self) -> List[DwfAnalogInFilter]:
-        """Get trigger filter info.
+        """Get |AnalogIn| trigger detector filter info.
 
         Returns:
             List[DwfAnalogInFilter]: A list of filters that can be configured for the trigger.
@@ -1559,12 +1565,12 @@ class AnalogIn(DwfDeviceSubApi):
         """Get |AnalogIn| trigger detector filter.
 
         Returns:
-            int: The currently configured trigger filter.
+            DwfAnalogInFilter: The currently configured trigger filter.
 
         Raises:
             DwfLibraryError: There was an error while getting the trigger filter.
         """
-        c_trigger_filter = typespec_ctypes.FILTER()
+        c_trigger_filter = typespec_ctypes.DwfAnalogInFilter()
         result = self.lib.FDwfAnalogInTriggerFilterGet(self.hdwf, c_trigger_filter)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
@@ -1692,6 +1698,9 @@ class AnalogIn(DwfDeviceSubApi):
     def triggerConditionInfo(self) -> List[DwfTriggerSlope]:
         """Get |AnalogIn| trigger detector condition info.
 
+        Returns:
+            List[DwfTriggerSlope]: A list of possible detector condition values.
+
         Raises:
             DwfLibraryError: There was an error while getting the trigger condition info.
         """
@@ -1794,11 +1803,11 @@ class AnalogIn(DwfDeviceSubApi):
         trigger_length = c_trigger_length.value
         return trigger_length
 
-    def triggerLengthConditionInfo(self) -> List[DwfTriggerLengthCondition]:
+    def triggerLengthConditionInfo(self) -> List[DwfAnalogInTriggerLengthCondition]:
         """Get |AnalogIn| trigger detector length condition info.
 
         Returns:
-            List[DwfTriggerLengthCondition]: The valid trigger length condition values that can be selected.
+            List[DwfAnalogInTriggerLengthCondition]: The valid trigger length condition values that can be selected.
 
         Raises:
             DwfLibraryError: There was an error while getting the trigger length condition info.
@@ -1808,14 +1817,15 @@ class AnalogIn(DwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
         tlc_bitset = c_tlc_bitset.value
-        tlc_list = [tlc for tlc in DwfTriggerLengthCondition if tlc_bitset & (1 << tlc.value)]
+        tlc_list = [tlc for tlc in DwfAnalogInTriggerLengthCondition if tlc_bitset & (1 << tlc.value)]
         return tlc_list
 
-    def triggerLengthConditionSet(self, trigger_length_condition: DwfTriggerLengthCondition) -> None:
+    def triggerLengthConditionSet(self, trigger_length_condition: DwfAnalogInTriggerLengthCondition) -> None:
         """Set |AnalogIn| trigger detector length condition.
 
         Parameters:
-            trigger_length_condition (DwfTriggerLengthCondition): The trigger length condition to be configured.
+            trigger_length_condition (DwfAnalogInTriggerLengthCondition):
+                The trigger length condition to be configured.
 
         Raises:
             DwfLibraryError: There was an error while setting the trigger length condition.
@@ -1826,22 +1836,22 @@ class AnalogIn(DwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def triggerLengthConditionGet(self) -> DwfTriggerLengthCondition:
+    def triggerLengthConditionGet(self) -> DwfAnalogInTriggerLengthCondition:
         """Get |AnalogIn| trigger detector length condition.
 
         Returns:
-            DwfTriggerLengthCondition: The currently configured trigger length condition.
+            DwfAnalogInTriggerLengthCondition: The currently configured trigger length condition.
 
         Raises:
             DwfLibraryError: There was an error while getting the trigger length condition.
         """
-        c_trigger_length_condition = typespec_ctypes.TRIGLEN()
+        c_trigger_length_condition = typespec_ctypes.DwfAnalogInTriggerLengthCondition()
         result = self.lib.FDwfAnalogInTriggerLengthConditionGet(
             self.hdwf,
             c_trigger_length_condition)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        trigger_length_condition = DwfTriggerLengthCondition(c_trigger_length_condition.value)
+        trigger_length_condition = DwfAnalogInTriggerLengthCondition(c_trigger_length_condition.value)
         return trigger_length_condition
 
     ####################################################################################################################
@@ -1872,7 +1882,7 @@ class AnalogIn(DwfDeviceSubApi):
         Raises:
             DwfLibraryError: There was an error while getting the sampling source.
         """
-        c_sampling_source = typespec_ctypes.TRIGSRC()
+        c_sampling_source = typespec_ctypes.DwfTriggerSource()
         result = self.lib.FDwfAnalogInSamplingSourceGet(self.hdwf, c_sampling_source)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
