@@ -4,14 +4,14 @@ import ctypes
 
 from typing import Tuple
 
-from pydwf.core.dwf_device_subapi import DwfDeviceSubApi
+from pydwf.core.dwf_device_subapi import AbstractDwfDeviceSubApi
 
 from pydwf.core.auxiliary.typespec_ctypes import typespec_ctypes
 from pydwf.core.auxiliary.constants import RESULT_SUCCESS
 from pydwf.core.auxiliary.enum_types import DwfAnalogIO
 
 
-class AnalogIO(DwfDeviceSubApi):
+class AnalogIO(AbstractDwfDeviceSubApi):
     """The |AnalogIO| class provides access to the analog I/O functionality of a |DwfDevice:link|.
 
     The |AnalogIO| methods are used to control the power supplies, reference voltage supplies, voltmeters, ammeters,
@@ -32,7 +32,7 @@ class AnalogIO(DwfDeviceSubApi):
         If auto-configure is enabled, the changes take immediate effect.
 
         Raises:
-            DwfLibraryError: There was an error while executing the reset operation.
+            DwfLibraryError: There was an error while executing the *reset* operation.
         """
         result = self.lib.FDwfAnalogIOReset(self.hdwf)
         if result != RESULT_SUCCESS:
@@ -42,7 +42,7 @@ class AnalogIO(DwfDeviceSubApi):
         """Configure the |AnalogIO| functionality.
 
         Raises:
-            DwfLibraryError: There was an error while executing the configure operation.
+            DwfLibraryError: There was an error while executing the *configure* operation.
         """
         result = self.lib.FDwfAnalogIOConfigure(self.hdwf)
         if result != RESULT_SUCCESS:
@@ -58,7 +58,7 @@ class AnalogIO(DwfDeviceSubApi):
         so this method does not return a value.
 
         Raises:
-            DwfLibraryError: There was an error while executing the status operation.
+            DwfLibraryError: There was an error while executing the *status* operation.
         """
         result = self.lib.FDwfAnalogIOStatus(self.hdwf)
         if result != RESULT_SUCCESS:
@@ -239,7 +239,7 @@ class AnalogIO(DwfDeviceSubApi):
         Raises:
             DwfLibraryError: There was an error while executing the operation.
         """
-        c_analog_io = typespec_ctypes.ANALOGIO()
+        c_analog_io = typespec_ctypes.DwfAnalogIO()
         result = self.lib.FDwfAnalogIOChannelNodeInfo(
             self.hdwf,
             channel_index,
