@@ -3,14 +3,14 @@
 from typing import Tuple
 import ctypes
 
-from pydwf.core.dwf_device_subapi import DwfDeviceSubApi
+from pydwf.core.dwf_device_subapi import AbstractDwfDeviceSubApi
 
 from pydwf.core.auxiliary.typespec_ctypes import typespec_ctypes
 from pydwf.core.auxiliary.constants import RESULT_SUCCESS
 from pydwf.core.auxiliary.exceptions import PyDwfError
 
 
-class DigitalCan(DwfDeviceSubApi):
+class DigitalCan(AbstractDwfDeviceSubApi):
     """The |DigitalCan| class provides access to the CAN bus protocol functionality of a |DwfDevice:link|.
 
     Attention:
@@ -24,7 +24,7 @@ class DigitalCan(DwfDeviceSubApi):
         """Reset the CAN bus protocol functionality.
 
         Raises:
-            DwfLibraryError: There was an error while executing the reset operation.
+            DwfLibraryError: There was an error while executing the *reset* operation.
         """
         result = self.lib.FDwfDigitalCanReset(self.hdwf)
         if result != RESULT_SUCCESS:
