@@ -2,13 +2,13 @@
 
 from typing import List, Tuple
 
-from pydwf.core.dwf_device_subapi import DwfDeviceSubApi
+from pydwf.core.dwf_device_subapi import AbstractDwfDeviceSubApi
 
 from pydwf.core.auxiliary.typespec_ctypes import typespec_ctypes
 from pydwf.core.auxiliary.constants import RESULT_SUCCESS
 
 
-class DigitalI2c(DwfDeviceSubApi):
+class DigitalI2c(AbstractDwfDeviceSubApi):
     """The |DigitalI2c| class provides access to the I²C protocol functionality of a |DwfDevice:link|.
 
     Attention:
@@ -22,7 +22,7 @@ class DigitalI2c(DwfDeviceSubApi):
         """Reset the I²C protocol instrument.
 
         Raises:
-            DwfLibraryError: There was an error while executing the reset operation.
+            DwfLibraryError: There was an error while executing the *reset* operation.
         """
         result = self.lib.FDwfDigitalI2cReset(self.hdwf)
         if result != RESULT_SUCCESS:
