@@ -1,12 +1,12 @@
 """The |pydwf.core.api.digital_io| module implements a single class: |DigitalIO|."""
 
-from pydwf.core.dwf_device_subapi import DwfDeviceSubApi
+from pydwf.core.dwf_device_subapi import AbstractDwfDeviceSubApi
 
 from pydwf.core.auxiliary.typespec_ctypes import typespec_ctypes
 from pydwf.core.auxiliary.constants import RESULT_SUCCESS
 
 
-class DigitalIO(DwfDeviceSubApi):
+class DigitalIO(AbstractDwfDeviceSubApi):
     """The |DigitalIO| class provides access to the digital I/O functionality of a |DwfDevice:link|.
 
     Attention:
@@ -29,7 +29,7 @@ class DigitalIO(DwfDeviceSubApi):
         If auto-configure is enabled, the values are immediately effectuated.
 
         Raises:
-            DwfLibraryError: There was an error while executing the reset operation.
+            DwfLibraryError: There was an error while executing the *reset* operation.
         """
         result = self.lib.FDwfDigitalIOReset(self.hdwf)
         if result != RESULT_SUCCESS:
@@ -41,7 +41,7 @@ class DigitalIO(DwfDeviceSubApi):
         This method does not have to be used if auto-configuration is enabled.
 
         Raises:
-            DwfLibraryError: There was an error while executing the configure operation.
+            DwfLibraryError: There was an error while executing the *configure* operation.
         """
         result = self.lib.FDwfDigitalIOConfigure(self.hdwf)
         if result != RESULT_SUCCESS:
@@ -54,7 +54,7 @@ class DigitalIO(DwfDeviceSubApi):
         so this method does not return a value.
 
         Raises:
-            DwfLibraryError: There was an error while executing the status operation.
+            DwfLibraryError: There was an error while executing the *status* operation.
         """
         result = self.lib.FDwfDigitalIOStatus(self.hdwf)
         if result != RESULT_SUCCESS:
