@@ -2,7 +2,7 @@
 
 from typing import Tuple, List
 
-from pydwf.core.dwf_device_subapi import DwfDeviceSubApi
+from pydwf.core.dwf_device_subapi import AbstractDwfDeviceSubApi
 
 from pydwf.core.auxiliary.typespec_ctypes import typespec_ctypes
 from pydwf.core.auxiliary.enum_types import (DwfTriggerSource, DwfTriggerSlope, DwfDigitalOutOutput, DwfDigitalOutType,
@@ -11,8 +11,9 @@ from pydwf.core.auxiliary.constants import RESULT_SUCCESS
 from pydwf.core.auxiliary.exceptions import PyDwfError
 
 
-class DigitalOut(DwfDeviceSubApi):
-    """The |DigitalOut| class provides access to the DigitalOut (pattern generator) instrument of a |DwfDevice:link|.
+class DigitalOut(AbstractDwfDeviceSubApi):
+    """The |DigitalOut| class provides access to the digital output (pattern generator) instrument of a
+    |DwfDevice:link|.
 
     Attention:
         Users of |pydwf| should not create instances of this class directly.
@@ -24,19 +25,39 @@ class DigitalOut(DwfDeviceSubApi):
     # pylint: disable=too-many-public-methods
 
     def reset(self) -> None:
-        """Reset the digital-out instrument."""
+        """Reset the digital-out instrument.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the *reset* operation.
+        """
         result = self.lib.FDwfDigitalOutReset(self.hdwf)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
     def configure(self, start: bool) -> None:
-        """Start or stop the digital-out instrument."""
+        """Start or stop the digital-out instrument.
+
+        Parameters:
+            start (int): Whether to start/stop the instrument.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the *configure* operation.
+        """
         result = self.lib.FDwfDigitalOutConfigure(self.hdwf, start)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
     def status(self) -> DwfState:
-        """Return the status of the digital-out instrument."""
+        """Return the status of the |DigitalOut| instrument.
+
+        Executing this method initiates a status request to the |DigitalOut| instrument and receives its response.
+
+        Returns:
+            DwfState: The status of the |DigitalOut| instrument.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the *status* operation.
+        """
         c_status = typespec_ctypes.DwfState()
         result = self.lib.FDwfDigitalOutStatus(self.hdwf, c_status)
         if result != RESULT_SUCCESS:
@@ -49,6 +70,9 @@ class DigitalOut(DwfDeviceSubApi):
 
         Returns:
             float: The digital-out clock frequency, in Hz.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
         """
         c_internal_clock_frequency = typespec_ctypes.c_double()
         result = self.lib.FDwfDigitalOutInternalClockInfo(self.hdwf, c_internal_clock_frequency)
@@ -64,7 +88,10 @@ class DigitalOut(DwfDeviceSubApi):
             This function is OBSOLETE. Use the generic DeviceControl.triggerInfo() method instead.
 
         Returns:
-            List[DwfTriggerSource]: a list of possible choices for the trigger source.
+            List[DwfTriggerSource]: A list of possible choices for the trigger source.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
         """
         c_trigger_source_bitset = typespec_ctypes.c_int()
         result = self.lib.FDwfDigitalOutTriggerSourceInfo(self.hdwf, c_trigger_source_bitset)
@@ -76,14 +103,28 @@ class DigitalOut(DwfDeviceSubApi):
         return trigger_source_list
 
     def triggerSourceSet(self, trigger_source: DwfTriggerSource) -> None:
-        """Set the trigger source."""
+        """Set the trigger source.
+
+        Parameters:
+            trigger_source (DwfTriggerSource): The trigger source to be configured.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
         result = self.lib.FDwfDigitalOutTriggerSourceSet(self.hdwf, trigger_source.value)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
     def triggerSourceGet(self) -> DwfTriggerSource:
-        """Get the currently active trigger source."""
-        c_trigger_source = typespec_ctypes.TRIGSRC()
+        """Get the currently active trigger source.
+
+        Returns:
+            DwfTriggerSource: The currently configured trigger source.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
+        c_trigger_source = typespec_ctypes.DwfTriggerSource()
         result = self.lib.FDwfDigitalOutTriggerSourceGet(self.hdwf, c_trigger_source)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
@@ -95,6 +136,9 @@ class DigitalOut(DwfDeviceSubApi):
 
         Returns:
             Tuple[float, float]: A tuple containing the minimal and maximal digital-out run duration, in seconds.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
         """
         c_run_duration_min = typespec_ctypes.c_double()
         c_run_duration_max = typespec_ctypes.c_double()
@@ -108,10 +152,16 @@ class DigitalOut(DwfDeviceSubApi):
     def runSet(self, run_duration: float) -> None:
         """Set duration for a single digital-out pulse sequence run, in seconds.
 
+        Parameters:
+            run_duration: The run duration, in seconds.
+
         Parameters:
             run_duration (float): Digital-out runtime, in seconds.
 
                 The value 0 is special; it means *forever*.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
         """
         result = self.lib.FDwfDigitalOutRunSet(self.hdwf, run_duration)
         if result != RESULT_SUCCESS:
@@ -122,6 +172,9 @@ class DigitalOut(DwfDeviceSubApi):
 
         Returns:
             float: digital-out run-time, in seconds.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
         """
         c_run_duration = typespec_ctypes.c_double()
         result = self.lib.FDwfDigitalOutRunGet(self.hdwf, c_run_duration)
@@ -141,7 +194,10 @@ class DigitalOut(DwfDeviceSubApi):
 
         Returns:
             int: The number of clock cycles until the nest state transition of the
-                     DigitalOut instrument's state machine.
+                     |DigitalOut| instrument's state machine.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
         """
         c_run_status = typespec_ctypes.c_double()
         result = self.lib.FDwfDigitalOutRunStatus(self.hdwf, c_run_status)
@@ -159,6 +215,9 @@ class DigitalOut(DwfDeviceSubApi):
         Returns:
             Tuple[float, float]: A tuple containing the minimal and maximal configurable wait durations that should
             precede a pulse-train output, expressed in seconds.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
         """
         c_wait_duration_min = typespec_ctypes.c_double()
         c_wait_duration_max = typespec_ctypes.c_double()
@@ -174,6 +233,9 @@ class DigitalOut(DwfDeviceSubApi):
 
         Parameters:
             wait_duration (float): Digital-out wait duration, in seconds.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
         """
         result = self.lib.FDwfDigitalOutWaitSet(self.hdwf, wait_duration)
         if result != RESULT_SUCCESS:
@@ -184,6 +246,9 @@ class DigitalOut(DwfDeviceSubApi):
 
         Returns:
             float: Digital-out wait duration, in seconds.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
         """
         c_wait_duration = typespec_ctypes.c_double()
         result = self.lib.FDwfDigitalOutWaitGet(self.hdwf, c_wait_duration)
@@ -198,6 +263,9 @@ class DigitalOut(DwfDeviceSubApi):
         Returns:
             Tuple[int, int]: A tuple containing the minimal and maximal repeat count for
                 digital-out pulse-sequence runs.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
         """
         c_repeat_min = typespec_ctypes.c_unsigned_int()
         c_repeat_max = typespec_ctypes.c_unsigned_int()
@@ -212,8 +280,11 @@ class DigitalOut(DwfDeviceSubApi):
         """Set repeat count for digital-out pulse-sequence runs.
 
         Parameters:
-            repeat: Repeat count.
+            repeat (int): Repeat count.
                 The value 0 is special; it means *forever*.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
         """
         result = self.lib.FDwfDigitalOutRepeatSet(self.hdwf, repeat)
         if result != RESULT_SUCCESS:
@@ -224,7 +295,10 @@ class DigitalOut(DwfDeviceSubApi):
 
         Returns:
             int: Repeat count.
-                The value 0 is special; it means *forever*.
+            The value 0 is special; it means *forever*.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
         """
         c_repeat = typespec_ctypes.c_unsigned_int()
         result = self.lib.FDwfDigitalOutRepeatGet(self.hdwf, c_repeat)
@@ -239,7 +313,10 @@ class DigitalOut(DwfDeviceSubApi):
         This number counts down as a digital output sequence is active.
 
         Returns:
-            int: Repeat count status.
+            int: The repeat count status.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
         """
         c_repeat_status = typespec_ctypes.c_unsigned_int()
         result = self.lib.FDwfDigitalOutRepeatStatus(self.hdwf, c_repeat_status)
@@ -253,6 +330,9 @@ class DigitalOut(DwfDeviceSubApi):
 
         Parameters:
             trigger_slope (DwfTriggerSlope): The trigger slope to be configured.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
         """
         result = self.lib.FDwfDigitalOutTriggerSlopeSet(self.hdwf, trigger_slope.value)
         if result != RESULT_SUCCESS:
@@ -263,6 +343,9 @@ class DigitalOut(DwfDeviceSubApi):
 
         Returns:
             DwfTriggerSlope: The currently configured trigger slope.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
         """
         c_trigger_slope = typespec_ctypes.DwfTriggerSlope()
         result = self.lib.FDwfDigitalOutTriggerSlopeGet(self.hdwf, c_trigger_slope)
@@ -277,6 +360,9 @@ class DigitalOut(DwfDeviceSubApi):
         Parameters:
             repeat_trigger_flag (bool): If True, not only the first, both also every successive run of the
                 pulse output sequence will wait until it receives a trigger.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
         """
         result = self.lib.FDwfDigitalOutRepeatTriggerSet(self.hdwf, repeat_trigger_flag)
         if result != RESULT_SUCCESS:
@@ -301,6 +387,9 @@ class DigitalOut(DwfDeviceSubApi):
 
         Returns:
             int: The number of digital output channels.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
         """
         c_channel_count = typespec_ctypes.c_int()
         result = self.lib.FDwfDigitalOutCount(self.hdwf, c_channel_count)
@@ -310,13 +399,31 @@ class DigitalOut(DwfDeviceSubApi):
         return channel_count
 
     def enableSet(self, channel_index: int, enable_flag: bool) -> None:
-        """Enable or disable a digital-out channel."""
+        """Enable or disable a digital-out channel.
+
+        Parameters:
+            channel_index (int): The digital pin to enable or disable.
+            enable_flag (bool): Whether to enable or disable the digital output.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
         result = self.lib.FDwfDigitalOutEnableSet(self.hdwf, channel_index, enable_flag)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
     def enableGet(self, channel_index: int) -> bool:
-        """Check if a specific digital-out channel is enabled."""
+        """Check if a specific digital pin is enabled for output.
+
+        Parameters:
+            channel_index (int): The digital pin.
+
+        Returns:
+            bool: Whether the digital pin is enabled as an output.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
         c_enable_flag = typespec_ctypes.c_int()
         result = self.lib.FDwfDigitalOutEnableGet(self.hdwf, channel_index, c_enable_flag)
         if result != RESULT_SUCCESS:
@@ -325,7 +432,14 @@ class DigitalOut(DwfDeviceSubApi):
         return enable_flag
 
     def outputInfo(self, channel_index: int) -> List[DwfDigitalOutOutput]:
-        """Get output info."""
+        """Get output info.
+
+        Returns:
+            List[DwfDigitalOutOutput]: A list of valid output settings.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
         c_output_bitset = typespec_ctypes.c_int()
         result = self.lib.FDwfDigitalOutOutputInfo(self.hdwf, channel_index, c_output_bitset)
         if result != RESULT_SUCCESS:
@@ -335,13 +449,31 @@ class DigitalOut(DwfDeviceSubApi):
         return output_list
 
     def outputSet(self, channel_index: int, output_value: DwfDigitalOutOutput) -> None:
-        """Set output."""
+        """Set output.
+
+        Parameters:
+            channel_index (int): The digital pin.
+            output_value (DwfDigitalOutOutput): The digital output setting.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
         result = self.lib.FDwfDigitalOutOutputSet(self.hdwf, channel_index, output_value.value)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
     def outputGet(self, channel_index: int) -> DwfDigitalOutOutput:
-        """Get output."""
+        """Get output.
+
+        Parameters:
+            channel_index (int): The digital pin.
+
+        Returns:
+            DwfDigitalOutOutput: The digital output setting.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
         c_output_value = typespec_ctypes.DwfDigitalOutOutput()
         result = self.lib.FDwfDigitalOutOutputGet(self.hdwf, channel_index, c_output_value)
         if result != RESULT_SUCCESS:
@@ -350,7 +482,14 @@ class DigitalOut(DwfDeviceSubApi):
         return output_value
 
     def typeInfo(self, channel_index: int) -> List[DwfDigitalOutType]:
-        """Get a list of possible output signal type values."""
+        """Get a list of possible output signal type values.
+
+        Returns:
+            List[DwfDigitalOutType]: A list of valid digital output types.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
         c_type_bitset = typespec_ctypes.c_int()
         result = self.lib.FDwfDigitalOutTypeInfo(self.hdwf, channel_index, c_type_bitset)
         if result != RESULT_SUCCESS:
@@ -360,13 +499,31 @@ class DigitalOut(DwfDeviceSubApi):
         return type_list
 
     def typeSet(self, channel_index: int, output_type: DwfDigitalOutType) -> None:
-        """Set output signal type."""
+        """Set output signal type.
+
+        Parameters:
+            channel_index (int): The digital pin.
+            output_type (DwfDigitalOutType): The digital output type.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
         result = self.lib.FDwfDigitalOutTypeSet(self.hdwf, channel_index, output_type.value)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
     def typeGet(self, channel_index: int) -> DwfDigitalOutType:
-        """Get currently configured output signal type."""
+        """Get currently configured output signal type.
+
+        Parameters:
+            channel_index (int): The digital pin.
+
+        Returns:
+            DwfDigitalOutType: The digital output type.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
         c_output_type = typespec_ctypes.DwfDigitalOutType()
         result = self.lib.FDwfDigitalOutTypeGet(self.hdwf, channel_index, c_output_type)
         if result != RESULT_SUCCESS:
@@ -375,7 +532,14 @@ class DigitalOut(DwfDeviceSubApi):
         return output_type
 
     def idleInfo(self, channel_index: int) -> List[DwfDigitalOutIdle]:
-        """Get a list of possible idle behavior setting values."""
+        """Get a list of valid idle behavior setting values.
+
+        Returns:
+            List[DwfDigitalOutIdle]: A list of valid digital idle options.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
         c_idle_bitset = typespec_ctypes.c_int()
         result = self.lib.FDwfDigitalOutIdleInfo(self.hdwf, channel_index, c_idle_bitset)
         if result != RESULT_SUCCESS:
@@ -385,13 +549,31 @@ class DigitalOut(DwfDeviceSubApi):
         return idle_list
 
     def idleSet(self, channel_index: int, idle_mode: DwfDigitalOutIdle) -> None:
-        """Set idle behavior setting."""
+        """Set idle behavior setting.
+
+        Parameters:
+            channel_index (int): The digital pin.
+            idle_mode (DwfDigitalOutIdle): The digital idle setting.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
         result = self.lib.FDwfDigitalOutIdleSet(self.hdwf, channel_index, idle_mode.value)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
     def idleGet(self, channel_index: int) -> DwfDigitalOutIdle:
-        """Get currently active idle behavior setting."""
+        """Get currently active idle behavior setting.
+
+        Parameters:
+            channel_index (int): The digital pin.
+
+        Returns:
+            DwfDigitalOutIdle: The current digital idle setting.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
         c_idle_mode = typespec_ctypes.DwfDigitalOutIdle()
         result = self.lib.FDwfDigitalOutIdleGet(self.hdwf, channel_index, c_idle_mode)
         if result != RESULT_SUCCESS:
@@ -400,28 +582,53 @@ class DigitalOut(DwfDeviceSubApi):
         return idle_mode
 
     def dividerInfo(self, channel_index: int) -> Tuple[int, int]:
-        """Get divider value range."""
-        c_divider_init_min = typespec_ctypes.c_unsigned_int()
-        c_divider_init_max = typespec_ctypes.c_unsigned_int()
+        """Get divider value range.
+
+        Returns:
+            Tuple[int, int]: The range of valid divider settings.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
+        c_divider_min = typespec_ctypes.c_unsigned_int()
+        c_divider_max = typespec_ctypes.c_unsigned_int()
         result = self.lib.FDwfDigitalOutDividerInfo(
             self.hdwf,
             channel_index,
-            c_divider_init_min,
-            c_divider_init_max)
+            c_divider_min,
+            c_divider_max)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        divider_init_min = c_divider_init_min.value
-        divider_init_max = c_divider_init_max.value
-        return (divider_init_min, divider_init_max)
+        divider_min = c_divider_min.value
+        divider_max = c_divider_max.value
+        return (divider_min, divider_max)
 
     def dividerInitSet(self, channel_index: int, divider_init: int) -> None:
-        """Set initial divider value."""
+        """Set initial divider value.
+
+        Parameters:
+            channel_index (int): The digital pin.
+            divider_init (int): The divider init setting.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
         result = self.lib.FDwfDigitalOutDividerInitSet(self.hdwf, channel_index, divider_init)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
     def dividerInitGet(self, channel_index: int) -> int:
-        """Get currently configured initial divider value."""
+        """Get currently configured initial divider value.
+
+        Parameters:
+            channel_index (int): The digital pin.
+
+        Returns:
+            int: The divider init setting.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
         c_divider_init = typespec_ctypes.c_unsigned_int()
         result = self.lib.FDwfDigitalOutDividerInitGet(self.hdwf, channel_index, c_divider_init)
         if result != RESULT_SUCCESS:
@@ -430,13 +637,31 @@ class DigitalOut(DwfDeviceSubApi):
         return divider_init
 
     def dividerSet(self, channel_index: int, divider: int) -> None:
-        """Set divider value."""
+        """Set divider value.
+
+        Parameters:
+            channel_index (int): The digital pin.
+            divider (int): The divider setting.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
         result = self.lib.FDwfDigitalOutDividerSet(self.hdwf, channel_index, divider)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
     def dividerGet(self, channel_index: int) -> int:
-        """Get currently configured divider value."""
+        """Get currently configured divider value.
+
+        Parameters:
+            channel_index (int): The digital pin.
+
+        Returns:
+            int: The divider setting.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
         c_divider = typespec_ctypes.c_unsigned_int()
         result = self.lib.FDwfDigitalOutDividerGet(self.hdwf, channel_index, c_divider)
         if result != RESULT_SUCCESS:
@@ -445,7 +670,17 @@ class DigitalOut(DwfDeviceSubApi):
         return divider
 
     def counterInfo(self, channel_index: int) -> Tuple[int, int]:
-        """Get counter value range."""
+        """Get counter value range.
+
+        Parameters:
+            channel_index (int): The digital pin.
+
+        Returns:
+            Tuple[int, int]: The range of valid counter settings.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
         c_counter_min = typespec_ctypes.c_unsigned_int()
         c_counter_max = typespec_ctypes.c_unsigned_int()
         result = self.lib.FDwfDigitalOutCounterInfo(
@@ -460,7 +695,16 @@ class DigitalOut(DwfDeviceSubApi):
         return (counter_min, counter_max)
 
     def counterInitSet(self, channel_index: int, high: bool, counter_init: int) -> None:
-        """Set initial signal value and initial counter value."""
+        """Set initial signal value and initial counter value.
+
+        Parameters:
+            channel_index (int): The digital pin.
+            high (bool): Whether to start High (True) or Low (False).
+            counter_init (int): The initial counter setting.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
         result = self.lib.FDwfDigitalOutCounterInitSet(
             self.hdwf,
             channel_index,
@@ -469,7 +713,18 @@ class DigitalOut(DwfDeviceSubApi):
             raise self.dwf.exception()
 
     def counterInitGet(self, channel_index: int) -> Tuple[bool, int]:
-        """Get initial signal value and initial counter value."""
+        """Get initial signal value and initial counter value.
+
+        Parameters:
+            channel_index (int): The digital pin.
+
+        Returns:
+            Tuple [bool, int]: Whether to start High (True) or Low (False),
+            and The initial counter setting.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
         c_high = typespec_ctypes.c_int()
         c_counter_init = typespec_ctypes.c_unsigned_int()
         result = self.lib.FDwfDigitalOutCounterInitGet(
@@ -483,13 +738,30 @@ class DigitalOut(DwfDeviceSubApi):
         return (high, counter_init)
 
     def counterSet(self, channel_index: int, low_count: int, high_count: int) -> None:
-        """Set counter durations for both the low and high signal output levels."""
+        """Set counter durations for both the low and high signal output levels.
+
+        Parameters:
+            channel_index (int): The digital pin.
+            low_count (int): The number of cycles the signal should be High.
+            high_count (int): The number of cycles the signal should be Low.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
         result = self.lib.FDwfDigitalOutCounterSet(self.hdwf, channel_index, low_count, high_count)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
     def counterGet(self, channel_index: int) -> Tuple[int, int]:
-        """Get counter durations for both the low and high signal output levels."""
+        """Get counter durations for both the low and high signal output levels.
+
+        Parameters:
+            channel_index (int): The digital pin.
+            Tuple[int, int]: The number of cycles the signal should be High, Low.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
         c_low_count = typespec_ctypes.c_unsigned_int()
         c_high_count = typespec_ctypes.c_unsigned_int()
         result = self.lib.FDwfDigitalOutCounterGet(self.hdwf, channel_index, c_low_count, c_high_count)
@@ -500,13 +772,17 @@ class DigitalOut(DwfDeviceSubApi):
         return (low_count, high_count)
 
     def dataInfo(self, channel_index: int) -> int:
-        """Return the maximum buffer size for the specified DigitalOut channel,
+        """Return the maximum buffer size for the specified |DigitalOut| channel,
         i.e., the number of custom data bits.
 
         Parameters:
             channel_index (int): the channel for which to obtain the data bits count.
+
         Returns:
             int: The number of custom data bits that can be specified for the channel.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
         """
         c_max_data_bits = typespec_ctypes.c_unsigned_int()
         result = self.lib.FDwfDigitalOutDataInfo(self.hdwf, channel_index, c_max_data_bits)
@@ -516,7 +792,15 @@ class DigitalOut(DwfDeviceSubApi):
         return max_data_bits
 
     def dataSet(self, channel_index: int, bits: str, tristate: bool = False) -> None:
-        """Set digital-out arbitrary channel data."""
+        """Set digital-out arbitrary channel data.
+
+        Parameters:
+            channel_index (int): the channel for which to obtain the data bits count.
+            bits (str): The bits, as a string.
+            tristate (bool): Whether to interpret the string as a tristate signal.
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
 
         if tristate:
             bits = bits.replace('1', '11').replace('0', '01').replace('Z', '00')
@@ -537,7 +821,16 @@ class DigitalOut(DwfDeviceSubApi):
             raise self.dwf.exception()
 
     def playDataSet(self, rg_bits: int, bits_per_sample: int, count_of_samples: int) -> None:
-        """Set playback data."""
+        """Set playback data.
+
+        Parameters:
+            rg_bits (int): (to be documented)
+            bits_per_sample (int): (to be documented)
+            count_of_samples (int): (to be documented)
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
         result = self.lib.FDwfDigitalOutPlayDataSet(
             self.hdwf,
             rg_bits,
@@ -546,8 +839,15 @@ class DigitalOut(DwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def playRateSet(self, rate_hz: float) -> None:
-        """Set playback rate."""
-        result = self.lib.FDwfDigitalOutPlayRateSet(self.hdwf, rate_hz)
+    def playRateSet(self, playback_rate: float) -> None:
+        """Set |DigitalOut| playback rate, in Hz.
+
+        Parameters:
+            playback_rate (float): The playback rate, in Hz.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
+        result = self.lib.FDwfDigitalOutPlayRateSet(self.hdwf, playback_rate)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
