@@ -2,14 +2,14 @@
 
 from typing import List
 
-from pydwf.core.dwf_device_subapi import DwfDeviceSubApi
+from pydwf.core.dwf_device_subapi import AbstractDwfDeviceSubApi
 
 from pydwf.core.auxiliary.typespec_ctypes import typespec_ctypes
 from pydwf.core.auxiliary.constants import RESULT_SUCCESS
 from pydwf.core.auxiliary.enum_types import DwfDigitalOutIdle
 
 
-class DigitalSpi(DwfDeviceSubApi):
+class DigitalSpi(AbstractDwfDeviceSubApi):
     """The |DigitalSpi| class provides access to the SPI protocol functionality of a |DwfDevice:link|.
 
     Attention:
@@ -23,7 +23,7 @@ class DigitalSpi(DwfDeviceSubApi):
         """Reset the SPI protocol support.
 
         Raises:
-            DwfLibraryError: There was an error while executing the reset operation.
+            DwfLibraryError: There was an error while executing the *reset* operation.
         """
         result = self.lib.FDwfDigitalSpiReset(self.hdwf)
         if result != RESULT_SUCCESS:
