@@ -3,13 +3,13 @@
 import ctypes
 from typing import Tuple
 
-from pydwf.core.dwf_device_subapi import DwfDeviceSubApi
+from pydwf.core.dwf_device_subapi import AbstractDwfDeviceSubApi
 
 from pydwf.core.auxiliary.typespec_ctypes import typespec_ctypes
 from pydwf.core.auxiliary.constants import RESULT_SUCCESS
 
 
-class DigitalUart(DwfDeviceSubApi):
+class DigitalUart(AbstractDwfDeviceSubApi):
     """The |DigitalUart| class provides access to the UART protocol functionality of a |DwfDevice:link|.
 
     Attention:
@@ -23,7 +23,7 @@ class DigitalUart(DwfDeviceSubApi):
         """Reset the UART protocol functionality.
 
         Raises:
-            DwfLibraryError: There was an error while executing the reset operation.
+            DwfLibraryError: There was an error while executing the *reset* operation.
         """
         result = self.lib.FDwfDigitalUartReset(self.hdwf)
         if result != RESULT_SUCCESS:
