@@ -1,4 +1,4 @@
-"""The |pydwf.core.dwf_library_subapi| module implements a single class: |DwfDeviceSubApi|."""
+"""The *pydwf.core.dwf_device_subapi* module implements a single class: *AbstractDwfDeviceSubApi*."""
 
 from typing import TYPE_CHECKING
 
@@ -6,7 +6,7 @@ if TYPE_CHECKING:
     from pydwf.core.dwf_device import DwfDevice
 
 
-class DwfDeviceSubApi:
+class AbstractDwfDeviceSubApi:
     """Abstract base class for the sub-API class members of a |DwfDevice:link|."""
 
     def __init__(self, device: 'DwfDevice'):
@@ -29,5 +29,5 @@ class DwfDeviceSubApi:
 
     @property
     def lib(self):
-        """Return the |ctypes| library."""
+        """Return the ctypes:link library."""
         return self.dwf.lib
