@@ -1,4 +1,4 @@
-"""The |pydwf.core.dwf_library_subapi| module implements a single class: |DwfLibrarySubApi|."""
+"""The |pydwf.core.dwf_library_subapi| module implements a single class: |AbstractDwfLibrarySubApi|."""
 
 from typing import TYPE_CHECKING
 
@@ -6,8 +6,9 @@ if TYPE_CHECKING:
     from pydwf.core.dwf_library import DwfLibrary
 
 
-class DwfLibrarySubApi:
-    """Abstract base class for the sub-API class members of a |DwfLibrary:link|."""
+class AbstractDwfLibrarySubApi:
+    """Abstract base class for the sub-API class members of a DwfLibrary."""
+
     def __init__(self, dwf: 'DwfLibrary'):
         self._dwf = dwf
 
@@ -18,5 +19,5 @@ class DwfLibrarySubApi:
 
     @property
     def lib(self):
-        """Return the |ctypes| library."""
+        """Return the ctypes library."""
         return self.dwf.lib
